==> rxswing-0.22.0-sources.jar: rx/subscriptions/SwingSubscriptions.java <==
/**
 * Copyright 2014 Netflix, Inc.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package rx.subscriptions;

import javax.swing.SwingUtilities;

import rx.Scheduler.Worker;
import rx.Subscription;
import rx.functions.Action0;
import rx.schedulers.SwingScheduler;

public final class SwingSubscriptions {

    private SwingSubscriptions() {
        // no instance
    }

    /**
     * Create an Subscription that always runs <code>unsubscribe</code> in the event dispatch thread.
     * 
     * @param unsubscribe
     * @return an Subscription that always runs <code>unsubscribe</code> in the event dispatch thread.
     */
    public static Subscription unsubscribeInEventDispatchThread(final Action0 unsubscribe) {
        return Subscriptions.create(new Action0() {
            @Override
            public void call() {
                if (SwingUtilities.isEventDispatchThread()) {
                    unsubscribe.call();
                } else {
                    final Worker inner = SwingScheduler.getInstance().createWorker();
                    inner.schedule(new Action0() {
                        @Override
                        public void call() {
                            unsubscribe.call();
                            inner.unsubscribe();
                        }
                    });
                }
            }
        });
    }
}

==> rxswing-0.25.0-sources.jar: rx/subscriptions/SwingSubscriptions.java <==
/**
 * Copyright 2014 Netflix, Inc.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package rx.subscriptions;

import javax.swing.SwingUtilities;

import rx.Scheduler.Worker;
import rx.Subscription;
import rx.functions.Action0;
import rx.schedulers.SwingScheduler;

public final class SwingSubscriptions {

    private SwingSubscriptions() {
        // no instance
    }

    /**
     * @deprecated All RxSwing sources now use subscribeOn to subscribe and unsubscribe on
     * the Swing thread.
     *
     * Create an Subscription that always runs <code>unsubscribe</code> in the event dispatch thread.
     * 
     * @param unsubscribe
     * @return an Subscription that always runs <code>unsubscribe</code> in the event dispatch thread.
     */
    @Deprecated
    public static Subscription unsubscribeInEventDispatchThread(final Action0 unsubscribe) {
        return Subscriptions.create(new Action0() {
            @Override
            public void call() {
                if (SwingUtilities.isEventDispatchThread()) {
                    unsubscribe.call();
                } else {
                    final Worker inner = SwingScheduler.getInstance().createWorker();
                    inner.schedule(new Action0() {
                        @Override
                        public void call() {
                            unsubscribe.call();
                            inner.unsubscribe();
                        }
                    });
                }
            }
        });
    }
}
